@@ -14,11 +14,11 @@ insertSeparators <- function(dates) {
   if (!any(stri_detect_regex(dates[!is.na(dates)], pattern = "[-/]"))) {
     if (all(suppressWarnings(as.integer(dates[!is.na(dates)]) &
                              !is.na(as.integer(dates[!is.na(dates)]))))) {
-      dates <- sapply(dates, function(x) {
+      dates <- vapply(dates, function(x) {
         stri_c(stri_sub(x, from = 1, to = 4), "-",
                stri_sub(x, from = 5, to = 6), "-",
                stri_sub(x, from = 7, to = 8))
-      })
+      }, character(1))
     }
   }
   dates
